/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.viewer.client.dashboards;

import java.util.Collection;
import java.util.HashMap;

import org.appspy.viewer.client.AbstractTreePanel;
import org.appspy.viewer.client.ViewerModule;
import org.appspy.viewer.client.dashboards.action.OpenDashboardAction;
import org.appspy.viewer.client.form.DashboardForm;
import org.appspy.viewer.client.form.ReportCategoryForm;

import com.google.gwt.user.client.rpc.AsyncCallback;
import com.gwtext.client.core.EventObject;
import com.gwtext.client.data.Node;
import com.gwtext.client.widgets.MessageBox;
import com.gwtext.client.widgets.tree.TreeNode;
import com.gwtext.client.widgets.tree.event.TreeNodeListenerAdapter;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class DashboardsMenuTreePanel extends AbstractTreePanel {
	
	protected TreeNode mRoot = null;

	public DashboardsMenuTreePanel(ViewerModule viewerModule) {

		setViewerModule(viewerModule);
		mRoot = new TreeNode("Dashboards");
		mRoot.setExpanded(true);

		setTitle("Dashboards");
		setIconCls("reports-menu-icon");
		setWidth(200);
		setHeight(400);
		setEnableDD(true);
		setRootNode(mRoot);
		setRootVisible(false);
		
		refreshDatas();
	}
	
	public void refreshDatas()
	{
		getViewerModule().getViewerModuleService().getDashboards(new AsyncCallback<Collection<DashboardForm>>(){
			
			public void onFailure(Throwable caught) {
				MessageBox.alert("Error", caught.getLocalizedMessage());
			}
			
			public void onSuccess(Collection<DashboardForm> result) {
				HashMap<String, ReportCategoryForm> cats = new HashMap<String, ReportCategoryForm>();
				for (DashboardForm dashboard : result) {
					cats.put(dashboard.getCategory().getName(), dashboard.getCategory());
				}
				for (ReportCategoryForm cat : cats.values()) {
					TreeNode catTreeNode = new TreeNode(cat.getName());
					catTreeNode.setIconCls("reports-menu-icon");
					mRoot.appendChild(catTreeNode);
					for (final DashboardForm dashboard : result) {
						if (dashboard.getCategory().getId() == cat.getId())
						{
							TreeNode reportTreeNode = new TreeNode(dashboard.getName());
							reportTreeNode.setIconCls("reports-menu-icon");
							catTreeNode.appendChild(reportTreeNode);
							reportTreeNode.addListener(new TreeNodeListenerAdapter() {
								
								@Override
								public void onClick(Node node, EventObject e) {
									
									AsyncCallback<DashboardForm> callback = new AsyncCallback<DashboardForm>(){
										
										public void onFailure(Throwable caught) {
											MessageBox.alert("Error", caught.getLocalizedMessage());
										}
										
										public void onSuccess(DashboardForm result) {
											new OpenDashboardAction(getViewerModule(), result, true).execute();
										}};
										
										getViewerModule().getViewerModuleService().getDashboard(dashboard.getId(), callback);
								}});
						}
					}
				}
			}});
	}
}
