/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.viewer.client.reports;

import java.util.Date;

import org.appspy.viewer.client.AbstractPanel;
import org.appspy.viewer.client.ViewerModule;
import org.appspy.viewer.client.form.ReportForm;
import org.appspy.viewer.client.paramchooser.ParamPropertyGridPanelFactory;
import org.appspy.viewer.client.paramchooser.ParamUtils;

import com.google.gwt.core.client.GWT;
import com.google.gwt.http.client.URL;
import com.google.gwt.user.client.ui.Frame;
import com.gwtext.client.core.EventObject;
import com.gwtext.client.core.Margins;
import com.gwtext.client.core.RegionPosition;
import com.gwtext.client.widgets.Button;
import com.gwtext.client.widgets.Panel;
import com.gwtext.client.widgets.Toolbar;
import com.gwtext.client.widgets.event.ButtonListenerAdapter;
import com.gwtext.client.widgets.layout.BorderLayout;
import com.gwtext.client.widgets.layout.BorderLayoutData;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class ReportPanel extends AbstractPanel {

	protected Frame mFrame = null;
	protected ReportForm mReport = null;
	protected Panel mPropertyPanel = null;
	
	public ReportPanel(ViewerModule viewerModule, ReportForm report) {
		
		super(viewerModule);
		mReport = report;
		mPropertyPanel = ParamPropertyGridPanelFactory.getPropertyGridPanel(viewerModule, report.getParams());

		setLayout(new BorderLayout());
		setAutoScroll(true);

		Toolbar toolbar = new Toolbar();
		toolbar.addSeparator();
		toolbar.addSpacer();
		toolbar.addFill();

        BorderLayoutData centerLayoutData = new BorderLayoutData(RegionPosition.CENTER);
        centerLayoutData.setMargins(new Margins(5, 5, 0, 5));
        centerLayoutData.setCMargins(new Margins(5, 5, 5, 5));
        centerLayoutData.setMinSize(200);
        centerLayoutData.setMinWidth(200);
        
        mFrame = new Frame();
        add(mFrame, centerLayoutData);
        refreshReport();
        
        // Reprendre le mme que celui de la ParamWindow
        mPropertyPanel.setTitle("Parameters");
        mPropertyPanel.setCollapsible(true);
        mPropertyPanel.setCollapsed(true);
        mPropertyPanel.setWidth(200);
        mPropertyPanel.addButton(new Button("OK", new ButtonListenerAdapter(){

			@Override
			public void onClick(Button button, EventObject e) {
				refreshReport();
			}}));
        
		BorderLayoutData eastLayoutData = new BorderLayoutData(RegionPosition.EAST);
        eastLayoutData.setMargins(new Margins(5, 0, 5, 5));
        eastLayoutData.setMinWidth(100);
        eastLayoutData.setSplit(true);
        
        add(mPropertyPanel, eastLayoutData);
	}

	public void refreshReport()
	{
        String queryString = ParamUtils.paramsToQueryString(mReport.getParams());
        String reportUrl = GWT.getModuleBaseURL() + "../org.appspy.viewer.birt.webapp/frameset?__report=" + URL.encode(mReport.getName()) + queryString + "&__refreshTime=" + new Date().getTime();
//        String reportUrl = GWT.getModuleBaseURL() + "test.html?__report=" + URL.encode(mReport.getName()) + queryString + "&__refreshTime=" + new Date().getTime();
        
        GWT.log("reportUrl = " + reportUrl, null);
        
        mFrame.setUrl(reportUrl);
	}
}
